forbidden_tags = [
    {"name": "style", "attrs": {}},
    {"name": "script", "attrs": {}},
    {"name": "span", "attrs": {"class": ["IPA"]}},
    {"name": "span", "attrs": {"class": ["unicode haudio"]}},
    {"name": "span", "attrs": {"class": ["mw-editsection"]}},
    {"name": "table", "attrs": {"class": ["infobox vcard"]}},
    {"name": "sup", "attrs": {"class": ["reference"]}},
    {"name": "div", "attrs": {"role": "navigation"}},
    {"name": "table", "attrs": {}},
    {"name": "span", "attrs": {"class": ["error", "mw-ext-cite-error"]}},
    {"name": "sup", "attrs": {"class": ["reference"]}},
]

new_line_tags = ["p", "br", "hr", "li", "ol", "dl", "dt", "dd"]
